import requests
from tqdm import tqdm
# List of files to download
files = [
	"brCTCF_a_R1_S53_R2_001.fastq.gz",
	"brCTCF_a_R1_S53_R1_001.fastq.gz",
	"brCTCF_R2_S56_R2_001.fastq.gz",
	"brCTCF_R2_S56_R1_001.fastq.gz",
	"brCTCF_R1_S52_R2_001.fastq.gz",
	"brCTCF_R1_S52_R1_001.fastq.gz"
]

# Public link to the folder
public_key = "https://disk.yandex.ru/d/8UsiatSg9zTubQ"

# Function to get direct download link for a file
def get_download_link(file_name):
    base_url = "https://cloud-api.yandex.net/v1/disk/public/resources/download"
    params = {'public_key': public_key, 'path': f'/{file_name}'}
    response = requests.get(base_url, params=params)
    if response.status_code == 200:
        return response.json()['href']
    else:
        print(f"Error getting download link for file {file_name}: {response.status_code} {response.text}")
        return None

# Function to download a file with progress bar
def download_file_with_progress(file_name):
    download_link = get_download_link(file_name)
    if download_link:
        file_response = requests.get(download_link, stream=True)
        if file_response.status_code == 200:
            total_size = int(file_response.headers.get('content-length', 0))
            with open(file_name, 'wb') as f, tqdm(total=total_size, unit='B', unit_scale=True, desc=file_name) as pbar:
                for data in file_response.iter_content(chunk_size=1024):
                    f.write(data)
                    pbar.update(len(data))
            print(f"File {file_name} downloaded successfully")
        else:
            print(f"Error downloading file {file_name}: {file_response.status_code} {file_response.text}")
    else:
        print(f"Unable to get download link for file {file_name}")

# Download all files
for file in files:
    download_file_with_progress(file)